| Title: | Bio-Logging Toolbox |
|---|---|
| Description: | An R-shiny application to visualize bio-loggers time series at a microsecond precision as Acceleration, Temperature, Pressure, Light intensity. It is possible to link behavioral labels extracted from 'BORIS' software <http://www.boris.unito.it> or manually written in a csv file. |
| Authors: | Sebastien Geiger [aut, cre] |
| Maintainer: | Sebastien Geiger <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.4.7 |
| Built: | 2026-05-28 07:52:31 UTC |
| Source: | https://github.com/sg4r/rblt |
A axytrek2h5 function for convert csv file to h5 file
axytrek2h5(filecsv = "", accres = 25, fileh5 = "")axytrek2h5(filecsv = "", accres = 25, fileh5 = "")
filecsv |
A input axytrek csv file. |
accres |
input number of data rate in 1 seconde |
fileh5 |
A output h5 data file. |
A cats2h5 function for convert csv file to h5 file
cats2h5(filecsv = "", accres = 50, fileh5 = "")cats2h5(filecsv = "", accres = 50, fileh5 = "")
filecsv |
A input cats csv file. |
accres |
input resolution |
fileh5 |
A output h5 data file. |
A demow_gui function for lunch a R-shiny application to plot datalogger view
demo_gui()demo_gui()
A demoaxytrek2h5 function build demo cats h5 file
demoaxytrek2h5(fileh5 = "", nbrow = 10000)demoaxytrek2h5(fileh5 = "", nbrow = 10000)
fileh5 |
input data H5 file |
nbrow |
number of row |
A democats2h5 function build demo cats h5 file
democats2h5(fileh5 = "", nbrow = 10000)democats2h5(fileh5 = "", nbrow = 10000)
fileh5 |
imput data h5 file |
nbrow |
number of row |
A democatsmkbe function for generate ramdom data
democatsmkbe(fbe = "", nbrow = 10, nbseq = 2)democatsmkbe(fbe = "", nbrow = 10, nbseq = 2)
fbe |
A outout be csv file. |
nbrow |
input number of data rate in 1 seconde |
nbseq |
input sequence lenght |
A demolul2h5 function build demo lul h5 file
demolul2h5(fileh5 = "", nbrow = 10000)demolul2h5(fileh5 = "", nbrow = 10000)
fileh5 |
A h5 data file. |
nbrow |
number of row |
A demowacu2h5 function build demo cats h5 file
demowacu2h5(fileh5 = "", nbrow = 10000)demowacu2h5(fileh5 = "", nbrow = 10000)
fileh5 |
A h5 data file. |
nbrow |
number of row |
A Logger reference class
namelogger display name
fileh5h5 data file name
filebehaviorbehavior file name
besepbehavior field separator character
besaturationthe ‘saturation’ value from 0 to 1
uizoomstartuizoomstart default value
uizoomenduizoomend default value
behaviorinit(besep, besaturation)init behavior list event
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
setextmatrix(m)set external matrix
sebastien geiger
A LoggerAxytrek reference class
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
A LoggerCats reference class
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
A LoggerData reference class
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
A LoggerList reference class
add(node)add new node in the list.
draw()draw the objec value
returns a list of String object representing the value
A LoggerLul reference class
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
A LoggerUI reference class
loglstlist of logger class
idid of curent loger view
ldatestartcurent start date
nbrowcourent row number
zoomhistoryhistory storage
gui()plot logger list
A LoggerWacu reference class
draw()draw the objec value
returns a String object representing the value
h5init()verify if h5 is correct version
initmetriclst()set metric list for this logger class
A lul2h5 function for concert lul csv file to h5 file
lul2h5(filecsv = "", fileh5 = "", sep = "\t")lul2h5(filecsv = "", fileh5 = "", sep = "\t")
filecsv |
A input LUL csv file. |
fileh5 |
A output h5 data file. |
sep |
input the field separator character. |
Metric reference class
nametitle metric in chart
colidstart column id
connbnumber of column for this metric
draw()draw the objec value
returns a String object representing the value
getmatrix(id)get matrix of elements
MetricList reference class
add(node)add new node in the list.
draw()draw the objec value
returns a list of String object representing the value
get()get all node from the list.
returns a list of node
getat(id)return element at id index.
returns the node @ id
getcolactive()get matrix col enable
getcolnames()get matrix col name
getmatrix()get matrix of elements
getsize()return lenght of element.
returns a non-negativ numeric
slctset(v)enable or disable metric view
v True or False vector
A wacu2h5 function for concert wacu csv file to h5 file
wacu2h5(filecsv = "", fileh5 = "", rtctick = 1, accres = 50, datestartstring = "")wacu2h5(filecsv = "", fileh5 = "", rtctick = 1, accres = 50, datestartstring = "")
filecsv |
A input WACU csv file. |
fileh5 |
A output h5 data file. |
rtctick |
tpl frequence |
accres |
acc frequence |
datestartstring |
A Date string in GMT |
A ZoomHistory reference class
draw()draw the objec value
returns a matrix of value
pop()pop one history position
push(s, e)push new history position in array.